@@ -1,4 +1,5 @@
-from .init import Module, error
+from setux.core.module import Module
+from setux.logger import error
 
 
 class Distro(Module):
