@@ -7,10 +7,10 @@ class Distro(Module):
     '''Show infos
     '''
     def deploy(self, target, **kw):
-        user = 'sudo' if target.sudo else target.distro.Login.name
-        os = target.OS
+        user = 'sudo' if target.sudo else target.login.name
+        os = target.os
         python = target.run('python3 -V')[1][0]
-        host = target.distro.Host
+        host = target.distro.host
 
         inst = '-' #len(list(target.Package.installed()))
         avail = '-' #len(list(target.Package.available()))
